# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pelican',
 'pelican.plugins.seo',
 'pelican.plugins.seo.seo_enhancer',
 'pelican.plugins.seo.seo_enhancer.html_enhancer',
 'pelican.plugins.seo.seo_report',
 'pelican.plugins.seo.seo_report.seo_analyzer',
 'pelican.plugins.seo.tests']

package_data = \
{'': ['*'], 'pelican.plugins.seo.seo_report': ['static/*', 'template/*']}

install_requires = \
['beautifulsoup4>=4.9,<5.0', 'pelican>=4.5,<5.0']

extras_require = \
{'markdown': ['markdown>=3.2.2,<4.0.0']}

setup_kwargs = {
    'name': 'pelican-seo',
    'version': '1.0.3',
    'description': 'Pelican plugin to improve SEO (Search Engine Optimization) to reach top positions on search engines.',
    'long_description': '# SEO Plugin for Pelican 🇫🇷\n\n[![Build Status](https://img.shields.io/github/workflow/status/pelican-plugins/seo/build)](https://github.com/pelican-plugins/seo/actions) [![PyPI Version](https://img.shields.io/pypi/v/pelican-seo)](https://pypi.org/project/pelican-seo/)\n\nThis plugin helps you improve your Pelican site SEO (Search Engine Optimization) to reach the top positions on search engines. To see what this SEO plugin can do for you, visit the [Usage](#usage) section.\n\n| Author          | GitHub                            |\n| :-------------: | :-------------------------------: |\n| Maëva Brunelles | https://github.com/MaevaBrunelles |\n\n## Why Use This Plugin?\n\nIf:\n\n* you are not familiar with SEO\n* you want an easy way to apply SEO fundamentals\n* you need help improving the SEO of your Pelican site\n\n… then this plugin is for you!\n\nSEO comes with two features to help you:\n\n* [SEO Report](#seo-report) — Generates an HTML report based on article analysis, indicating what is good, what could be improved, and what is problematic. Useful if you want to improve the ranking of your articles.\n* [SEO Enhancer](#seo-enhancer) — Generates robot indexing guidelines, HTML tags, and structured data. Useful if you want to control how your site appears in search engine results.\n\n## Installation\n\nThis plugin can be installed via:\n\n    python -m pip install pelican-seo\n\n## Requirements\n\nThe above installation step should automatically install Beautiful Soup 4, which the SEO plugin requires. The following command will manually install this dependency:\n\n    python -m pip install beautifulsoup4\n\nPlease keep in mind that the `SITEURL` Pelican setting must be defined in order for this plugin to function as intended.\n\n## Usage\n\nYou can enable/disable features by setting them to `True` or `False` in your Pelican settings. The default is `True` for both.\n\n```python\n# settings.py\nSEO_REPORT = True  # To enable this feature\nSEO_ENHANCER = False  # To disable this feature\n```\n\nThe SEO plugin runs when you [generate your site](https://docs.getpelican.com/en/stable/quickstart.html#generate-your-site). If you want to see SEO logging in your console output, add the `--verbose` option to your `pelican` invocation:\n\n```bash\n$ pelican content --verbose\n-> SEO plugin initialized\n-> SEO plugin - SEO Report: seo_report.html file created\n-> SEO plugin - SEO Enhancement: robots.txt file created\n-> Writing /output/my-first-review.html\n-> SEO plugin - SEO Enhancement: Done for /output/my-first-review.html\nDone: Processed 1 articles, 0 drafts, 0 pages, 0 hidden pages and 0 draft pages in 0.17 seconds.\n```\n\n### SEO Report\n\nThe SEO plugin analyzes all your articles and pages and generate an SEO HTML report in your Pelican project root: `seo-report.html`\n\nExample:\n\n![SEO report example](docs/seo-report-example.png)\n\nYou can set limits for article and page analysis in the plugin settings.py. By default, it\'s set up to 10 articles and 10 pages.\n\n```python\nSEO_ARTICLES_LIMIT = 10\nSEO_PAGES_LIMIT = 10\n```\n\nThe SEO analysis begins with the most recent articles/pages, according to the `date` metadata, and is focused on the following criteria:\n\n* Page title: `<title></title>`\n* Page description: `<meta name="description" content="" />`\n* Heading content: `<h1></h1>`\n* Internal site links: `<a href="SITEURL/..."></a>`\n\nThe above information is defined in your source content, such as the following example Markdown file:\n\n```markdown\nTitle: Page Title\nDescription: Page Description\n\n# Heading Content\n\n[Internal link](https://example.com/about.html)\n```\n\nOnce the SEO analysis has generated a report, optimize your articles and pages according to the report’s recommendations, and then repeat the analysis to see whether everything comes up green.\n\n### SEO Enhancer\n\nThe SEO Enhancer module generates the following for you:\n\n* robots file\n* HTML enhancements\n* structured data\n\n#### Robots.txt File\n\nThe generated `robots.txt` file indicates to search engines which pages they should index. By default, search engine bots are allowed to crawl and index all pages.\n\n```\nUser-agent: *\n```\n\nTo disallow crawling and/or forbid indexing for a given article/page, add the following to your article/page metadata:\n\n```\nDisallow: True\nNoindex: True\n```\n\nA `robots.txt` file will be generated at your web site root, as per the `OUTPUT_PATH` setting (Pelican’s default is `output/`).\n\n```\n# robots.txt\nUser-agent: *\n\nDisallow: example.html\nNoindex: other-example.html\n```\n\n#### Canonical URL Tag\n\nThe SEO Enhancer automatically adds canonical link metadata to `<head>` tags in order to avoid presenting duplicate content to search engines.\n\n```html\n<link rel="canonical" href="<SITEURL>/example.html" />\n```\n\n#### Structured Data\n\nThe SEO Enhancer automatically adds structured data in the `<head>` tag in order to improve the display of result snippets in search engines. Articles will have both article schema and breadcrumb schema, while pages will only have breadcrumb schema.\n\nStructured data is based on [Schema.org](https://schema.org/) vocabulary, with `JSON-LD` encoding. Note that schemas generated by default are compliant with Schema.org but not (by default) Google-compliant. The latter requires additional metadata.\n\n##### Breadcrumb Schema\n\nBased on [BreadcrumbList schema](https://schema.org/BreadcrumbList):\n\n```json-ld\n{\n    "@context": "https://schema.org",\n    "@type": "BreadcrumbList",\n    "itemListElement": [\n        {\n            "@type": "ListItem",\n            "position": :n=1:,\n            "name": :Sitename:,\n            "item": :SITEURL:\n        },\n        {\n            "@type": "ListItem",\n            "position": :n+1:,\n            "name": :name:,\n            "item": :url:\n        },\n        {\n            "@type": "ListItem",\n            "position": :n+x:,\n            "name": :name:,\n            "item": :url:\n        }\n    ]\n}\n```\n\nEach path element has a `ListItem`, even folders, so it’s better to create a user-friendly page for those (otherwise you’ll get your server’s default page).\n\n##### Article schema\n\nBased on [Article schema](https://schema.org/Article):\n\n```json-ld\n{\n    "@context": "https://schema.org",\n    "@type": "Article",\n    "author": {\n        "@type": "Person",\n        "name": :author:\n    },\n    "publisher": {\n        "@type": "Organization",\n        "name": :sitename:,\n        "logo": {\n            "@type": "ImageObject",\n            "url": :logo:\n        }\n    },\n    "headline": :title:,\n    "about": :category:,\n    "datePublished": :publication_date:,\n    "image": :image:\n}\n```\n\n`:logo:` and `:image:` fields are not required by Schema.org but are by Google.\n\nTo populate the `:logo:` field, add a `LOGO` setting to your Pelican settings file containing an absolute link to your site logo image:\n\n```\n# pelicanconf.py\nLOGO = "https://www.example.com/logo.jpg"\n```\n\nTo populate the `:image:` field, add an image metadata field to your Markdown/reST content:\n\n```\n# article.md\nImage: https://www.example.com/article-image.jpg\n\n# article.rst\n:image: https://www.example.com/article-image.jpg\n```\n\n## Contributing\n\nContributions are welcome and much appreciated. Every little bit helps. You can contribute by improving the documentation, adding missing features, and fixing bugs. You can also help out by reviewing and commenting on [existing issues][].\n\nTo start contributing to this plugin, review the [Contributing to Pelican][] documentation, beginning with the **Contributing Code** section.\n\n[existing issues]: https://github.com/pelican-plugins/seo/issues\n[Contributing to Pelican]: https://docs.getpelican.com/en/latest/contribute.html\n',
    'author': 'Maëva Brunelles',
    'author_email': 'contact@tremacorp.fr',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/pelican-plugins/seo',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
